@@ -7,34 +7,6 @@ import shutil
 from openpyxl.utils import column_index_from_string
 from datetime import datetime
 
-def RunRFTestSuite(project_dir, ts_name, ts_subfolders, reports_folder):
-    """
-    Runs a Robot Framework Test Suite and moves the test result files to the Reports 
-    folder relevant to the project main folder (parameter: project_dir) for a given 
-    test suite folders (parameter: ts_subfolders) and test suite name (parameter: ts_name)
-    Note:  Based on the Robot Framework template structure
-    
-    Use Example:   Run RF Test Suite    ${EXECDIR}  TS001_TC001_Register_Your_Organization   Test_Suites\\TS001_Register_Your_Organization    TS001_Register_Your_Organization
-    """
-     
-    current_date_time = datetime.now()
-    timestamp = current_date_time.strftime("%Y%m%d")
-    
-    change_dir = "cd " + project_dir
-
-    a = "robot -d "
-    b = "Reports" + "\\" + reports_folder + "\\" + ts_name + "-" + timestamp + " --timestampoutputs -r "
-    c = "_reports.html -o "
-    d = "_output.xml -l "
-    e = "_log.html "
-    f = ts_subfolders + "\\" + ts_name + ".robot"
-
-    cmds = a + b + ts_name + c + ts_name + d + ts_name + e + f
-
-    os.system(change_dir)
-
-    os.system(cmds)
-
 def EmailFormatValidator(email):
     """
      Validates if an email address is in the correct format and returns a
@@ -278,3 +250,22 @@ def GetAllDataFromExcelSheet(fileName, sheetname) :
          curr_row += 1
          testData.append(dataRows)
     return dataRows
+
+def WriteToExcelFile(filename, sheetname, data_value, row_index, col_index):
+
+     """
+     Write a value into a cell in the worksheet row and column
+        that is passed in to the function
+     """
+
+     wb = openpyxl.load_workbook(filename)
+     ws =  wb.get_sheet_by_name(sheetname)
+
+     r = int(row_index)
+     c = int(col_index)
+
+
+     ws.cell(row=r, column=c).value = ''
+     ws.cell(row=r, column=c).value = data_value    #enter the data_value in cell row=r and column=c
+
+     wb.save(filename) # Save the workbook
\ No newline at end of file
